@@ -1,19 +1,19 @@
 # onvif/__init__.py
 
 from .client import ONVIFClient
-from .operator import ONVIFOperator, CacheMode
+from .operator import CacheMode
 from .utils import (
     ONVIFWSDL,
     ONVIFOperationException,
     ONVIFErrorHandler,
     ZeepPatcher,
     ONVIFDiscovery,
+    ONVIFParser,
 )
 from .cli import main as ONVIFCLI
 
 __all__ = [
     "ONVIFClient",
-    "ONVIFOperator",
     "CacheMode",
     "ONVIFWSDL",
     "ONVIFOperationException",
@@ -21,4 +21,5 @@ __all__ = [
     "ZeepPatcher",
     "ONVIFCLI",
     "ONVIFDiscovery",
+    "ONVIFParser",
 ]
