@@ -69,6 +69,15 @@ ONVIF_NAMESPACE_MAP = {
 }
 
 
+def _is_valid_json(s: str) -> bool:
+    """Check if a string is valid JSON without raising exceptions."""
+    try:
+        json.loads(s)
+    except ValueError:
+        return False
+    return True
+
+
 def parse_json_params(params_str: str) -> Dict[str, Any]:
     """Parse parameters from a JSON string or key=value pairs into a dict.
     Supports:
@@ -80,10 +89,8 @@ def parse_json_params(params_str: str) -> Dict[str, Any]:
         return {}
 
     # If the whole string is valid JSON, return it directly
-    try:
-        return json.loads(params_str)
-    except Exception:
-        pass
+    if _is_valid_json(params_str):
+        return json.loads(params_str)  # We know it's valid, so this should not fail
 
     # Otherwise parse key=value pairs but allow JSON values for the right-hand side
     # We split tokens while respecting quoted strings using shlex, but must not
@@ -213,8 +220,8 @@ def get_service_methods(service_obj) -> list:
     methods = []
     for attr_name in dir(service_obj):
         if not attr_name.startswith("_") and callable(getattr(service_obj, attr_name)):
-            # Skip operator attribute
-            if attr_name != "operator":
+            # Skip helper methods
+            if attr_name not in ["type", "desc", "operations"]:
                 methods.append(attr_name)
     return sorted(methods)
 
@@ -351,15 +358,6 @@ def get_method_documentation(service_obj, method_name: str) -> Optional[Dict[str
     except Exception:
         return None
 
-    return None
-
-
-def truncate_output(text: str, max_length: int = 1000) -> str:
-    """Truncate output if too long"""
-    if len(text) <= max_length:
-        return text
-    return text[:max_length] + f"\n... (truncated, {len(text)} total chars)"
-
 
 def colorize(text: str, color: str) -> str:
     """Add color to text for terminal output"""
@@ -384,8 +382,12 @@ def colorize(text: str, color: str) -> str:
                 kernel32.SetConsoleMode(
                     h_stdout, mode.value | ENABLE_VIRTUAL_TERMINAL_PROCESSING
                 )
-            except Exception:
-                pass  # Fallback to no colors if error
+            except (ImportError, AttributeError, OSError):
+                # Specific exceptions that can occur:
+                # - ImportError: ctypes not available
+                # - AttributeError: Windows API functions not available
+                # - OSError: Console mode setting failed
+                colorize._colors_enabled = False
 
     colors = {
         "red": "\033[91m",
@@ -625,7 +627,7 @@ def get_device_available_services(client) -> list:
                     # Security namespace has multiple bindings
                     available_services.extend(
                         [
-                            "advancedsecurity",
+                            "security",
                             "jwt",
                             "keystore",
                             "tlsserver",
@@ -635,6 +637,100 @@ def get_device_available_services(client) -> list:
                         ]
                     )
 
+    # Additional check: Try to call security.GetServiceCapabilities() to verify availability
+    # This is necessary because Security service might not be reported in GetServices/GetCapabilities
+    # Use caching to avoid calling GetServiceCapabilities repeatedly
+    if "security" not in available_services:
+        # Check if we've already tried to get security capabilities
+        if not hasattr(client, "_security_capabilities_checked"):
+            client._security_capabilities_checked = False
+            client._security_capabilities = None
+
+        if not client._security_capabilities_checked:
+            # First time check - call GetServiceCapabilities and cache result
+            try:
+                security_service = client.security()
+                # Try to call GetServiceCapabilities to verify the service is actually available
+                caps = security_service.GetServiceCapabilities()
+
+                # Cache the capabilities for future use
+                client._security_capabilities = caps
+                client._security_capabilities_checked = True
+
+            except Exception:
+                # Security service not available, mark as checked
+                client._security_capabilities_checked = True
+                client._security_capabilities = None
+
+        # Use cached capabilities
+        if client._security_capabilities is not None:
+            caps = client._security_capabilities
+
+            # If successful, add main security service
+            available_services.append("security")
+
+            # Check each sub-service capability to determine availability
+            # Only add sub-services if their corresponding capability is not None
+            if (
+                hasattr(caps, "KeystoreCapabilities")
+                and caps.KeystoreCapabilities is not None
+            ):
+                available_services.append("keystore")
+
+            if (
+                hasattr(caps, "TLSServerCapabilities")
+                and caps.TLSServerCapabilities is not None
+            ):
+                available_services.append("tlsserver")
+
+            if (
+                hasattr(caps, "Dot1XCapabilities")
+                and caps.Dot1XCapabilities is not None
+            ):
+                available_services.append("dot1x")
+
+            if (
+                hasattr(caps, "AuthorizationServer")
+                and caps.AuthorizationServer is not None
+            ):
+                available_services.append("authorizationserver")
+
+            if hasattr(caps, "MediaSigning") and caps.MediaSigning is not None:
+                available_services.append("mediasigning")
+
+    # Additional check for JWT service: Try to call jwt.GetJWTConfiguration()
+    # JWT doesn't have a capability in GetServiceCapabilities, so we need to test it directly
+    if "jwt" not in available_services:
+        # Check if we've already tried to get JWT availability
+        if not hasattr(client, "_jwt_checked"):
+            client._jwt_checked = False
+            client._jwt_available = None
+
+        if not client._jwt_checked:
+            # First time check - try to call GetJWTConfiguration and cache result
+            try:
+                # JWT service requires xaddr from security service
+                # Try to construct xaddr from security service endpoint
+                protocol = "https" if client.common_args["use_https"] else "http"
+                default_xaddr = f"{protocol}://{client.common_args['host']}:{client.common_args['port']}/onvif/AdvancedSecurity"
+
+                # Try to call GetJWTConfiguration to verify JWT is available
+                jwt_service = client.jwt(xaddr=default_xaddr)
+                jwt_service.GetJWTConfiguration()
+
+                # If successful, JWT is available
+                client._jwt_available = True
+                client._jwt_checked = True
+
+            except Exception:
+                # JWT service not available, mark as checked
+                client._jwt_checked = True
+                client._jwt_available = False
+
+        # Use cached JWT availability
+        if client._jwt_available:
+            available_services.append("jwt")
+
     return sorted(list(set(available_services)))  # Remove duplicates and sort
 
 
@@ -823,8 +919,12 @@ def _load_imported_schemas(root, schema_context: dict, namespaces: dict):
                                 },
                                 namespaces,
                             )
-                    except Exception:
-                        pass  # Skip if can't parse
+                    except (etree.XMLSyntaxError, OSError, PermissionError):
+                        # Skip files that can't be parsed or accessed:
+                        # - XMLSyntaxError: malformed XML
+                        # - OSError: file access issues
+                        # - PermissionError: insufficient permissions
+                        continue
 
         # Process includes
         for include_elem in schema.findall("xs:include", namespaces):
@@ -859,8 +959,12 @@ def _load_imported_schemas(root, schema_context: dict, namespaces: dict):
                                 },
                                 namespaces,
                             )
-                    except Exception:
-                        pass  # Skip if can't parse
+                    except (etree.XMLSyntaxError, OSError, PermissionError):
+                        # Skip files that can't be parsed or accessed:
+                        # - XMLSyntaxError: malformed XML
+                        # - OSError: file access issues
+                        # - PermissionError: insufficient permissions
+                        continue
 
 
 def parse_message_from_wsdl(
@@ -1173,8 +1277,10 @@ def resolve_complex_type(
                 # Get documentation
                 attr_doc = None
                 attr_doc_elem = attr.find("xs:annotation/xs:documentation", namespaces)
-                if attr_doc_elem is not None and attr_doc_elem.text:
-                    attr_doc = clean_documentation_html(attr_doc_elem.text.strip())
+                if attr_doc_elem is not None:
+                    full_text = extract_documentation_text(attr_doc_elem)
+                    if full_text:
+                        attr_doc = clean_documentation_html(full_text)
 
                 attr_info = {
                     "name": attr_name,
@@ -1205,8 +1311,10 @@ def resolve_complex_type(
             # Get documentation
             child_doc = None
             doc_elem = elem.find("xs:annotation/xs:documentation", namespaces)
-            if doc_elem is not None and doc_elem.text:
-                child_doc = clean_documentation_html(doc_elem.text.strip())
+            if doc_elem is not None:
+                full_text = extract_documentation_text(doc_elem)
+                if full_text:
+                    child_doc = clean_documentation_html(full_text)
 
             child_info = {
                 "name": child_name,
@@ -1296,8 +1404,10 @@ def parse_inline_complex_type(
         # Get documentation
         attr_doc = None
         attr_doc_elem = attr.find("xs:annotation/xs:documentation", namespaces)
-        if attr_doc_elem is not None and attr_doc_elem.text:
-            attr_doc = clean_documentation_html(attr_doc_elem.text.strip())
+        if attr_doc_elem is not None:
+            full_text = extract_documentation_text(attr_doc_elem)
+            if full_text:
+                attr_doc = clean_documentation_html(full_text)
 
         attr_info = {
             "name": attr_name,
@@ -1345,8 +1455,10 @@ def parse_inline_complex_type(
                 # Get documentation
                 attr_doc = None
                 attr_doc_elem = attr.find("xs:annotation/xs:documentation", namespaces)
-                if attr_doc_elem is not None and attr_doc_elem.text:
-                    attr_doc = clean_documentation_html(attr_doc_elem.text.strip())
+                if attr_doc_elem is not None:
+                    full_text = extract_documentation_text(attr_doc_elem)
+                    if full_text:
+                        attr_doc = clean_documentation_html(full_text)
 
                 attr_info = {
                     "name": attr_name,
@@ -1377,8 +1489,10 @@ def parse_inline_complex_type(
             # Get documentation
             child_doc = None
             doc_elem = elem.find("xs:annotation/xs:documentation", namespaces)
-            if doc_elem is not None and doc_elem.text:
-                child_doc = clean_documentation_html(doc_elem.text.strip())
+            if doc_elem is not None:
+                full_text = extract_documentation_text(doc_elem)
+                if full_text:
+                    child_doc = clean_documentation_html(full_text)
 
             child_info = {
                 "name": child_name,
