@@ -1,10 +1,10 @@
 # onvif/services/devicemgmt.py
 
 from ..operator import ONVIFOperator
-from ..utils import ONVIFWSDL
+from ..utils import ONVIFWSDL, ONVIFService
 
 
-class Device:
+class Device(ONVIFService):
     def __init__(self, xaddr=None, **kwargs):
         # References:
         # - ONVIF Core
@@ -171,8 +171,8 @@ class Device:
     def GetCapabilities(self, Category=None):
         return self.operator.call("GetCapabilities", Category=Category)
 
-    def SetDPAddresses(self, DPAddresses=None):
-        return self.operator.call("SetDPAddresses", DPAddresses=DPAddresses)
+    def SetDPAddresses(self, DPAddress=None):
+        return self.operator.call("SetDPAddresses", DPAddress=DPAddress)
 
     def GetHostname(self):
         return self.operator.call("GetHostname")
@@ -411,3 +411,6 @@ class Device:
 
     def SetHashingAlgorithm(self, Algorithm):
         return self.operator.call("SetHashingAlgorithm", Algorithm=Algorithm)
+
+    def UpgradeFirmware(self, Version):
+        return self.operator.call("UpgradeFirmware", Version=Version)
